@@ -10,16 +10,26 @@
 set -eaux
 uname -a
 
+# HOMEBREW_NO_INSTALLED_DEPENDENTS_CHECK=1
+HOMEBREW_NO_INSTALL_CLEANUP=1
+
+arch=$(arch)
+[[ $arch == "i386" ]] && arch="x86_64" # GitHub Actions on macOS declare i386
+
+ARCH="arch -$arch"
+
 source scripts/common.sh
 
 brew_home=$(brew config | grep HOMEBREW_PREFIX | sed 's/.* //')
 
-brew install cmake ninja pkg-config automake
+$ARCH brew install cmake ninja pkg-config automake
 
-brew cat cairo
+# brew cat cairo
 
 # We don't want a dependency on X11
 brew cat cairo | sed '
+s/xcb=enabled/xcb=disabled/
+s/xlib=enabled/xlib=disabled/
 s/enable-tee/disable-tee/
 s/enable-xcb/disable-xcb/
 s/enable-xlib/disable-xlib/
@@ -27,20 +37,15 @@ s/enable-xlib-xrender/disable-xlib-xrender/
 s/enable-quartz-image/disable-quartz-image/' > cairo.rb
 
 cat cairo.rb
-brew uninstall --ignore-dependencies  cairo || true
-brew install --build-from-source --formula cairo.rb
 
-# brew cat pango | sed 's/introspection=enabled/introspection=disabled/' > pango.rb
+$ARCH brew install pango
+$ARCH brew install netcdf
+$ARCH brew install proj
+$ARCH brew install libaec
 
-# cat pango.rb
 
-# brew install --build-from-source ./pango.rb
+$ARCH brew reinstall --build-from-source --formula cairo.rb
 
-brew install pango
-
-brew install netcdf
-brew install proj
-brew install libaec
 
 for p in  netcdf proj pango cairo
 do
@@ -48,17 +53,16 @@ do
     echo "brew $p $v" >> versions
 done
 
-# -DCMAKE_OSX_ARCHITECTURES="x86_64;arm64"
-
 # Build eccodes
 
 cd $TOPDIR/build-ecmwf/eccodes
 
 # We disable JASPER because of a linking issue. JPEG support comes from
 # other librarues
-$TOPDIR/src/ecbuild/bin/ecbuild \
+$ARCH $TOPDIR/src/ecbuild/bin/ecbuild \
     $TOPDIR/src/eccodes \
     -GNinja \
+    -DCMAKE_OSX_ARCHITECTURES=$arch \
     -DCMAKE_BUILD_TYPE=RelWithDebInfo \
     -DENABLE_PYTHON=0 \
     -DENABLE_FORTRAN=0 \
@@ -71,14 +75,15 @@ $TOPDIR/src/ecbuild/bin/ecbuild \
     -DCMAKE_INSTALL_RPATH=$TOPDIR/install/lib $ECCODES_EXTRA_CMAKE_OPTIONS
 
 cd $TOPDIR
-cmake --build build-ecmwf/eccodes --target install
+$ARCH cmake --build build-ecmwf/eccodes --target install
 
 # Build magics
 
 cd $TOPDIR/build-ecmwf/magics
-$TOPDIR/src/ecbuild/bin/ecbuild \
+$ARCH $TOPDIR/src/ecbuild/bin/ecbuild \
     $TOPDIR/src/magics \
     -GNinja \
+    -DCMAKE_OSX_ARCHITECTURES=$arch \
     -DCMAKE_BUILD_TYPE=RelWithDebInfo \
     -DENABLE_PYTHON=0 \
     -DENABLE_FORTRAN=0 \
@@ -88,9 +93,7 @@ $TOPDIR/src/ecbuild/bin/ecbuild \
     -DCMAKE_INSTALL_RPATH=$TOPDIR/install/lib
 
 cd $TOPDIR
-cmake --build build-ecmwf/magics --target install
-
-
+$ARCH cmake --build build-ecmwf/magics --target install
 
 # Create wheel
 rm -fr dist wheelhouse ecmwflibs/share
@@ -102,6 +105,14 @@ rm -fr ecmwflibs/share/proj/*.txt
 rm -fr ecmwflibs/share/proj/*.pol
 rm -fr ecmwflibs/share/magics/efas
 
+# echo "================================================================================"
+# for n in install/lib/*.dylib
+# do
+#     echo $n
+#     ./scripts/libs-macos.py $n
+# done
+# echo "================================================================================"
+
 strip -S install/lib/*.dylib
 
 ./scripts/versions.sh > ecmwflibs/versions.txt
